<?php
$servidor = "127.0.0.1";
$usuario = "root"; 
$contraseña = ""; 
$baseDeDatos = "pagina_db"; 

$conexion = new mysqli($servidor, $usuario, $contraseña, $baseDeDatos);

if ($conexion->connect_error) {
    die("Error de conexión: " . $conexion->connect_error);
}

$votos = [];

if ($_SERVER["REQUEST_METHOD"] === "POST" && isset($_POST['opcion'])) {
    $opcion = $_POST['opcion'];

    $conexion->begin_transaction();
    try {

        $sql = "UPDATE pintura SET cantidad = cantidad + 1 WHERE opcion = ?";
        $stmt = $conexion->prepare($sql);
        if ($stmt === false) {
            throw new Exception("Error al preparar la consulta: " . $conexion->error);
        }
        $stmt->bind_param("s", $opcion);
        $stmt->execute();

        if ($stmt->affected_rows === 0) {
            throw new Exception("No se encontró la opción: " . htmlspecialchars($opcion));
        }

        $conexion->commit();
    } catch (Exception $e) {
        $conexion->rollback();
        die("Error al registrar el voto: " . $e->getMessage());
    } finally {
        $stmt->close();
    }
}

$result = $conexion->query("SELECT opcion, cantidad FROM pintura");
if ($result === false) {
    die("Error al recuperar los resultados: " . $conexion->error);
}

while ($row = $result->fetch_assoc()) {
    $votos[$row['opcion']] = $row['cantidad'];
}

$conexion->close();
?>


<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Mejor Pintura</title>
    <link rel="stylesheet" href="styles.css">
    <style>
        body {
            margin: 0;
            font-family: Arial, sans-serif;
            background: linear-gradient(to right, #6a11cb, #2575fc);
            color: white;
        }
        .container {
            background: rgba(255, 255, 255, 0.9);
            padding: 50px;
            border-radius: 15px;
            max-width: 1200px; /* Contenedor más amplio */
            margin: 50px auto;
            text-align: center;
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.2);
        }
        h1 {
            font-size: 28px;
            margin-bottom: 20px;
            color: #333;
        }
        p {
            margin-bottom: 20px;
            font-size: 18px;
            color: black;
        }
        .opciones-container {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(250px, 1fr)); /* Ajuste automático de columnas */
            gap: 20px;
            justify-items: center;
            margin-bottom: 20px;
        }
        label {
            cursor: pointer;
            background: #007BFF;
            color: white;
            padding: 15px;
            border-radius: 8px;
            transition: background-color 0.3s;
            width: 100%;
            text-align: center;
            display: flex;
            justify-content: center;
            align-items: center;
            height: auto;
            position: relative;
        }
        label:hover {
            background: #0056b3;
        }
        input[type="radio"] {
            display: none;
        }
        .image-opcion {
            width: 100%;
            max-width: 200px; /* Ajuste de tamaño máximo para las imágenes */
            height: auto;
            border-radius: 8px;
        }
        .label-overlay {
            position: absolute;
            top: -10px;
            bottom: -10px;
            left: -10px;
            right: -10px;
            background: rgba(0, 123, 255, 0.5);
            border-radius: 8px;
            z-index: -1;
        }
        button {
            background-color: #28a745;
            color: white;
            padding: 12px 25px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
            margin-top: 20px;
            transition: background-color 0.3s;
            display: block;
            margin-left: auto;
            margin-right: auto; /* Esto centra el botón */
        }
        button:hover {
            background-color: #218838;
        }

        /* Nueva clase para centrar las últimas tres opciones */
        .extra-opciones {
            justify-self: center;  /* Centra estas opciones dentro de su celda */
        }

        /* Ajustes para el contenedor de las opciones */
        @media screen and (min-width: 1000px) {
            .opciones-container {
                grid-template-columns: repeat(5, 1fr); /* 5 columnas */
            }

            .opciones-container label:nth-child(5),
            .opciones-container label:nth-child(6),
            .opciones-container label:nth-child(7),
            .opciones-container label:nth-child(8),
            .opciones-container label:nth-child(9),
            .opciones-container label:nth-child(10),
            .opciones-container label:nth-child(11),
            .opciones-container label:nth-child(12),
            .opciones-container label:nth-child(13),
            .opciones-container label:nth-child(14),
            .opciones-container label:nth-child(15),
            .opciones-container label:nth-child(16),
            .opciones-container label:nth-child(17),
            .opciones-container label:nth-child(18),
            .opciones-container label:nth-child(19) {
                justify-self: center; /* Centra todas las opciones */
            }
        }

        /* Modal (ventana emergente) */
        .modal {
            display: none; /* Por defecto está oculto */
            position: fixed;
            z-index: 1; /* Se coloca sobre otros elementos */
            padding-top: 100px; /* Espaciado desde la parte superior */
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            overflow: auto;
            background-color: rgb(0, 0, 0); /* Fondo negro */
            background-color: rgba(0, 0, 0, 0.9); /* Fondo negro con opacidad */
        }

        /* El contenido dentro del modal */
        .modal-content {
            margin: auto;
            display: block;
            width: 80%; /* Ancho de la imagen */
            max-width: 700px;
        }

        /* El botón para cerrar el modal */
        .close {
            position: absolute;
            top: 20px;
            right: 25px;
            color: #f1f1f1;
            font-size: 35px;
            font-weight: bold;
            transition: color 0.3s;
        }

        .close:hover,
        .close:focus {
            color: #bbb;
            text-decoration: none;
            cursor: pointer;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Mejor Pintura</h1>
        <p>Elige tu pintura favorita:</p>
        <form id="votingForm" method="POST">
            <div class="opciones-container">
                <!-- Opción 1 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 1" required>
                    <img class="image-opcion" src="1p.jpg" alt="Opción 1" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 2 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 2">
                    <img class="image-opcion" src="2p.jpg" alt="Opción 2" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 3 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 3">
                    <img class="image-opcion" src="3p.jpg" alt="Opción 3" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 4 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 4">
                    <img class="image-opcion" src="4p.jpg" alt="Opción 4" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 5 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 5">
                    <img class="image-opcion" src="5p.jpg" alt="Opción 5" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 6 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 6">
                    <img class="image-opcion" src="6p.jpg" alt="Opción 6" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 7 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 7">
                    <img class="image-opcion" src="7p.jpg" alt="Opción 7" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 8 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 8">
                    <img class="image-opcion" src="8p.jpg" alt="Opción 8" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 9 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 9">
                    <img class="image-opcion" src="9p.jpg" alt="Opción 9" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 10 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 10">
                    <img class="image-opcion" src="10p.jpg" alt="Opción 10" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 11 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 11">
                    <img class="image-opcion" src="11p.jpg" alt="Opción 11" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 12 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 12">
                    <img class="image-opcion" src="12p.jpg" alt="Opción 12" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 13 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 13">
                    <img class="image-opcion" src="13p.jpg" alt="Opción 13" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 14 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 14">
                    <img class="image-opcion" src="14p.jpg" alt="Opción 14" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 15 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 15">
                    <img class="image-opcion" src="15p.jpg" alt="Opción 15" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 16 -->
                <label class="opcion">
                    <input type="radio" name="opcion" value="Opción 16">
                    <img class="image-opcion" src="16p.jpg" alt="Opción 16" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 17 (Extra, centrado) -->
                <label class="opcion extra-opciones">
                    <input type="radio" name="opcion" value="Opción 17">
                    <img class="image-opcion" src="17p.jpg" alt="Opción 17" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 18 (Extra, centrado) -->
                <label class="opcion extra-opciones">
                    <input type="radio" name="opcion" value="Opción 18">
                    <img class="image-opcion" src="18p.jpg" alt="Opción 18" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
                <!-- Opción 19 (Extra, centrado) -->
                <label class="opcion extra-opciones">
                    <input type="radio" name="opcion" value="Opción 19">
                    <img class="image-opcion" src="19p.jpg" alt="Opción 19" onclick="openModal(this)">
                    <div class="label-overlay"></div>
                </label>
            </div>
            <button type="submit">Votar</button>
        </form>
    </div>

    <!-- Modal (ventana emergente) -->
    <div id="modal" class="modal">
        <span class="close" onclick="closeModal()">&times;</span>
        <img class="modal-content" id="img01">
    </div>

    <script>
        // Función para abrir el modal
        function openModal(image) {
            var modal = document.getElementById("modal");
            var modalImg = document.getElementById("img01");
            modal.style.display = "block";
            modalImg.src = image.src;
        }

        // Función para cerrar el modal
        function closeModal() {
            var modal = document.getElementById("modal");
            modal.style.display = "none";
        }
    </script>
</body>
</html>
